# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-11-24 02:57
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Service',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=120)),
                ('description', models.TextField(max_length=500)),
                ('price', models.FloatField()),
            ],
        ),
        migrations.CreateModel(
            name='ServiceCombo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.CreateModel(
            name='Combo',
            fields=[
                ('service_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='service.Service')),
                ('specification', models.CharField(max_length=120)),
            ],
            bases=('service.service',),
        ),
        migrations.AddField(
            model_name='servicecombo',
            name='service_in_combo',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='service_in_combo', to='service.Service'),
        ),
        migrations.AddField(
            model_name='servicecombo',
            name='service_combo',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='service_combo', to='service.Combo'),
        ),
        migrations.AddField(
            model_name='combo',
            name='services',
            field=models.ManyToManyField(related_name='services', through='service.ServiceCombo', to='service.Service'),
        ),
    ]
